==> calligra_2.7.2.orig.tar.xz: calligra-2.7.2/libs/koreport/wrtembed/reportsceneview.cpp <==
/*
 * OpenRPT report writer and rendering engine
 * Copyright (C) 2001-2007 by OpenMFG, LLC (info@openmfg.com)
 * Copyright (C) 2007-2008 by Adam Pigg (adam@piggz.co.uk)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

//
// ReportSceneView method implementations
//
#include "reportsceneview.h"
#include "KoReportDesigner.h"

#include <kdebug.h>

ReportSceneView::ReportSceneView(KoReportDesigner * designer, QGraphicsScene *scene, QWidget * parent)
 : QGraphicsView(scene, parent)
{
    m_reportDesigner = designer;

    viewport()->setMouseTracking(true);
    setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);

    setCacheMode(QGraphicsView::CacheBackground);
    setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    setDragMode(QGraphicsView::RubberBandDrag);
    setFrameStyle(0);
    m_reportDesigner->setActiveScene(scene);

}

ReportSceneView::~ReportSceneView()
{
    viewport()->setMouseTracking(false);
}

//TODO check
void ReportSceneView::resizeContents(QSize s)
{
    setMinimumSize(s);
    setMaximumSize(s);
}

KoReportDesigner * ReportSceneView::designer()
{
    return m_reportDesigner;
}

void ReportSceneView::mouseReleaseEvent(QMouseEvent * e)
{
    m_reportDesigner->sectionMouseReleaseEvent(this, e);
    QGraphicsView::mouseReleaseEvent(e);
}

QSize ReportSceneView::sizeHint() const
{
    //kDebug() <<  scene()->width() << "x" << scene()->height();
    return QSize(scene()->width(), scene()->height());
}

==> calligra_2.9.7.orig.tar.xz: calligra-2.9.7/libs/koreport/wrtembed/reportsceneview.cpp <==
/*
 * OpenRPT report writer and rendering engine
 * Copyright (C) 2001-2007 by OpenMFG, LLC (info@openmfg.com)
 * Copyright (C) 2007-2008 by Adam Pigg (adam@piggz.co.uk)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

//
// ReportSceneView method implementations
//
#include "reportsceneview.h"
#include "KoReportDesigner.h"

#include <kdebug.h>

ReportSceneView::ReportSceneView(KoReportDesigner * designer, QGraphicsScene *scene, QWidget * parent)
 : QGraphicsView(scene, parent)
{
    m_reportDesigner = designer;

    viewport()->setMouseTracking(true);
    setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);

    setCacheMode(QGraphicsView::CacheBackground);
    setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    setDragMode(QGraphicsView::RubberBandDrag);
    setFrameStyle(0);
    m_reportDesigner->setActiveScene(scene);

}

ReportSceneView::~ReportSceneView()
{
    viewport()->setMouseTracking(false);
}

//TODO check
void ReportSceneView::resizeContents(QSize s)
{
    setMinimumSize(s);
    setMaximumSize(s);
}

KoReportDesigner * ReportSceneView::designer()
{
    return m_reportDesigner;
}

void ReportSceneView::mousePressEvent(QMouseEvent * e)
{
    m_reportDesigner->sectionMousePressEvent(this, e);
    QGraphicsView::mousePressEvent(e);
}

void ReportSceneView::mouseReleaseEvent(QMouseEvent * e)
{
    m_reportDesigner->sectionMouseReleaseEvent(this, e);
    QGraphicsView::mouseReleaseEvent(e);
}

QSize ReportSceneView::sizeHint() const
{
    //kDebug() <<  scene()->width() << "x" << scene()->height();
    return QSize(scene()->width(), scene()->height());
}
